==> providence-jax-rs-2.2.0-sources.jar: net/morimekta/providence/jax/rs/DefaultProvidenceMessageBodyReader.java <==
/*
 * Copyright 2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.jax.rs;

import net.morimekta.providence.serializer.BinarySerializer;
import net.morimekta.providence.serializer.DefaultSerializerProvider;
import net.morimekta.providence.serializer.FastBinarySerializer;
import net.morimekta.providence.serializer.JsonSerializer;

import javax.ws.rs.Consumes;

/**
 * Default message body reader for standard providence serializers.
 */
@Consumes({
                  BinarySerializer.MEDIA_TYPE,
                  BinarySerializer.ALT_MEDIA_TYPE,
                  JsonSerializer.MEDIA_TYPE,
                  JsonSerializer.JSON_MEDIA_TYPE
          })
public class DefaultProvidenceMessageBodyReader extends ProvidenceMessageBodyReader {
    public DefaultProvidenceMessageBodyReader() {
        super(new DefaultSerializerProvider());
    }
}

==> providence-jax-rs-2.6.0-sources.jar: net/morimekta/providence/jax/rs/DefaultProvidenceMessageBodyReader.java <==
/*
 * Copyright 2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.jax.rs;

import net.morimekta.providence.serializer.BinarySerializer;
import net.morimekta.providence.serializer.DefaultSerializerProvider;
import net.morimekta.providence.serializer.JsonSerializer;

import javax.ws.rs.Consumes;

/**
 * Default message body reader for standard providence serializers.
 */
@Consumes({
                  JsonSerializer.JSON_MEDIA_TYPE,
                  JsonSerializer.MEDIA_TYPE,
                  BinarySerializer.MEDIA_TYPE,
                  BinarySerializer.ALT_MEDIA_TYPE,
          })
public class DefaultProvidenceMessageBodyReader extends ProvidenceMessageBodyReader {
    public DefaultProvidenceMessageBodyReader() {
        super(new DefaultSerializerProvider(JsonSerializer.JSON_MEDIA_TYPE));
    }
}
